Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobe® PDF format. The Adobe® Reader® is a free download. |
| Rows per Page

379 documents were found matching the selected criteria.
Page: [ 1] 2 3 4 next

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
State v. Wilson | 14CA16 | Indictment; Subject Matter Jurisdiction | Delaney | 7/24/2014 | 2014-Ohio-3286
In re C.W. | 2013 CA 0027 | Permanent custody | Wise | 7/24/2014 | 2014-Ohio-3284
State v. Brown | 14CA3 | Petition for post-conviction relief/Untimely/Res judicata | Baldwin | 7/22/2014 | 2014-Ohio-3222
State v. Hassinger | 13-COA-038 | Motion to dismiss on disorderly conduct charge | Farmer | 7/22/2014 | 2014-Ohio-3214
State v. Dover | 2014 CA 00073 | Motion for plain error review | Wise | 7/21/2014 | 2014-Ohio-3200
Osborne v. N. Canton | 2013 CA 00246 | Emergency ordinance | Wise | 7/21/2014 | 2014-Ohio-3199
State v. Foust | 2013 CA 00218 | OMVI suppression | Wise | 7/21/2014 | 2014-Ohio-3198
Massillon City School Dist. Bd. of Edn. v. Massillon Edn. Assn. | 2013 CA 00208 | Arbitration - reduction in force | Wise | 7/21/2014 | 2014-Ohio-3197
Sheridan v. Davila | 2013 CA 00203 | Small claims action | Wise | 7/21/2014 | 2014-Ohio-3196
Holcomb v. Naples | 2013CA00214 | Personal Jurisdiction/Long Arm Statute | Hoffman | 7/21/2014 | 2014-Ohio-3287
State v. Radcliff | 13-CA-118 | Motion to Supress; Reasonable Suspicion; Pat-Down | Delaney | 7/18/2014 | 2014-Ohio-3221
Parrott v. Jones | 13-CA-110 | Tortious Interference With a Business Relationship; Manifest Weight of the Evidence | Delaney | 7/18/2014 | 2014-Ohio-3220
Caetano v. Mangus | 13-CA-107 | Child Support Modification; Voluntary Underemployed | Delaney | 7/18/2014 | 2014-Ohio-3219
State v. Jervis | 13-CA-97 | Telephone Harassment; Intent; Manifest Weight | Delaney | 7/18/2014 | 2014-Ohio-3218
State v. Agee | 13 CA 71 | guilty plea colloquy | Wise | 7/18/2014 | 2014-Ohio-3215
Burke v. French | 14CA1 | Contempt; Violation of Visitation Orders | Delaney | 7/17/2014 | 2014-Ohio-3217
Kinkade v. Noblet | 14CA4 | Parade float injury - primary assumption of the risk | Farmer | 7/17/2014 | 2014-Ohio-3172
State v. Hamilton | 13CA93 | Manifest weight; joinder of trials; ineffective counsel | Farmer | 7/17/2014 | 2014-Ohio-3171
State v. Jenkins | 14 CA 17 | Motion for resentencing | Wise | 7/17/2014 | 2014-Ohio-3150
HSBC Bank, USA v. Maust | 13 CA 82 | Foreclosure | Wise | 7/16/2014 | 2014-Ohio-3170
Tucker v. Pfirsch | 2014 CA 0036 | Eviction/ratification | Wise | 7/16/2014 | 2014-Ohio-3151
Snell v. Snell | 13CA80 | Division of Property and Debts/Separation Agreement Not Enforceable | Hoffman | 7/16/2014 | 2014-Ohio-3285
Bank of Am., NA v. Wise | 14 CA 11 | Foreclosure | Wise | 7/14/2014 | 2014-Ohio-3091
In re C.K. | 2014CA00024 | Permanent custody | Farmer | 7/14/2014 | 2014-Ohio-3103
Greenwich Ins. Co. v. Leonard Ins. Servs., Agency, Inc. | 2013 CA 00233 | Implied indemnity | Wise | 7/14/2014 | 2014-Ohio-3102
State v. Triplett | 2013CA00209 | Batson; prosecutorial misconduct; ineffective assistance of counsel | Gwin | 7/14/2014 | 2014-Ohio-3101
In re K.J. | 14CA7 | Motion for visitation, best interest of child | Gwin | 7/14/2014 | 2014-Ohio-3100
State v. Pettry | 14 CA 00002 | Indigent Defendant; waiver of court costs. | Wise | 7/14/2014 | 2014-Ohio-3099
Vakilian v. Malek | 14 CAE 01 0008 | Civ.R. 60(B) personal jurisdiction | Farmer | 7/14/2014 | 2014-Ohio-3098
State v. Amos | 14-COA-01 | Abandon animals | Gwin | 7/14/2014 | 2014-Ohio-3097
State v. Wofford | 2013CA00186 | Aggravated Burglary - Domestic Violence | Hoffman | 7/14/2014 | 2014-Ohio-3122
State v. Henderson | 13CA98 | Sentencing/Allied offenses of similar import/Rape/Kidnapping/IAC/Insufficient evidence/Manifest weight | Baldwin | 7/14/2014 | 2014-Ohio-3121
Minor v. Eldridge | 13-CA-00010 | Easement by necessity; Money Damages - Rent and Trespass | Hoffman | 7/14/2014 | 2014-Ohio-3120
J & J Oil & Gas, Inc. v. MDR Properties II, L.L.C. | 13CA23 | Title to underground propane tank | Baldwin | 7/14/2014 | 2014-Ohio-3119
State v. Rankin | 2013AP120048 | Aggravated menacing | Gwin | 7/11/2014 | 2014-Ohio-3104
State v. Jones | 14-COA-002 | Post conviction relief petition denied. | Farmer | 7/11/2014 | 2014-Ohio-3064
State v. Tinney | 13CA18 | Crim.R.32.1 motion granted -"manifest injustice" | Farmer | 7/10/2014 | 2014-Ohio-3053
Byers v. Byers | 13-CA-00012 | Transfer to federal court/Dismissed/Failure to state reasons | Baldwin | 7/10/2014 | 2014-Ohio-3052
Coen v. Dennison | 2013 AP 08 0036 | Summary judgment - properly granted - no evidence establish genuine issues of material fact. | Hoffman | 7/10/2014 | 2014-Ohio-3094
State v. Ryther-Collins | 13-CA-115 | Assault on peace officer | Gwin | 7/10/2014 | 2014-Ohio-3093
In re G.N.C. | 130CA-112 | Custody | Gwin | 7/10/2014 | 2014-Ohio-3092
State v. Fisher | 13 CA 35 | Warrantless Entry Into Home; Arrest Warrant; Domestic Violence Affidavit | Delaney | 7/9/2014 | 2014-Ohio-3029
State v. Recinos | 14CA9 | Forfeiture | Gwin | 7/7/2014 | 2014-Ohio-3021
Whetstone v. Binner | 13 CA 47 | Punitive Damages | Gwin | 7/7/2014 | 2014-Ohio-3018
Woodie v. Patterson | 2013CA0022 | Divorce - Motiion for Contempt | Gwin | 7/7/2014 | 2014-Ohio-3017
Mathias v. Pleasant Twp. Bd. of Trustees | 14-CA-6 | Administrative appeal/Termination of fire chief | Baldwin | 7/3/2014 | 2014-Ohio-3019
State v. Schorr | 13-CA-45 | Warrantless Search; Curtilage; Protective Sweep | Delaney | 7/2/2014 | 2014-Ohio-2992
State v. Henderson | 13-CA-61 | Continuing jurisdiction on competency; speedy trial violation | Farmer | 7/2/2014 | 2014-Ohio-2991
State v. Smith | 13-CA-44 | No contest pleas; Crim.R.11 colloquy insufficient | Farmer | 7/2/2014 | 2014-Ohio-2990
State v. Dozier | 2013 CA 00185 | Ineffective assistance | Wise | 6/30/2014 | 2014-Ohio-2925
Clemens Trust v. Levengood | 13CA33 | Summary judgment on foreclosure and lien priority | Farmer | 6/30/2014 | 2014-Ohio-2922
State v. Gibby | 13-CA-81 | Community control/Revocation proceedings/Calculation of community control period | Baldwin | 6/30/2014 | 2014-Ohio-2921
State v. Rucker | 13-CA-0009 | Restitution/No abuse of discretion | Baldwin | 6/30/2014 | 2014-Ohio-3020
State ex rel. Papa v. Starkey | 2014CA00001 | Petition for Writ of Mandamus | Delaney | 6/30/2014 | 2014-Ohio-2989
State v. Brown | 2014CA00005 | Untimely Petition for Post Conviction Relief; Res Judicata | Delaney | 6/30/2014 | 2014-Ohio-2988
Veach v. Chuchanis | 2014CA00026 | Change of Beneficiary | Gwin | 6/30/2014 | 2014-Ohio-2949
State v. Martin | 14-CA-5 | OVI motion to suppress | Gwin | 6/30/2014 | 2014-Ohio-2948
Bigelow v. Am. Fam. Ins. | 2013CA0024 | Consumer Sales Practice Act, Attorney fees, Expert fees | Gwin | 6/30/2014 | 2014-Ohio-2945
State v. Picard | 13CA95 | Resentencing/Abuse of discretion | Baldwin | 6/27/2014 | 2014-Ohio-2924
State v. Richard-Bey | CT2014-0012, CT2014-0013 | Sentencing: imposition of post-release control | Farmer | 6/27/2014 | 2014-Ohio-2923
State v. McElfresh | 13-CA-74 | Recusal of Trial Court Judge; Findings Necessary for Consecutive Sentences | Delaney | 6/27/2014 | 2014-Ohio-2947
In re J.W. | 2014CA00032 | Permanent Custody | Delaney | 6/26/2014 | 2014-Ohio-2950
Blackmore v. S. Cent. Power Co. | 13-CA-54 | Electrocution; Negligence; Proximate Cause | Delaney | 6/26/2014 | 2014-Ohio-2946
NationStar Mtge., L.L.C. v. Purnell | 13-CA-74 | Civ.R. 60(B) ruling without evidentiary hearing | Farmer | 6/25/2014 | 2014-Ohio-2824
State v. Campbell | 13-CA-57 | Motion to withdraw guilty plea prior to sentencing | Farmer | 6/25/2014 | 2014-Ohio-2823
State ex rel. Holder v. Deweese | 14CA02 | Writ | Gwin | 6/24/2014 | 2014-Ohio-2753
State v. Brown | 2013CA00167 | Criminal Rule 29 Acquittal on Rape Charge insufficient evidence; consecutive sentences; ineffective assistance | Hoffman | 6/23/2014 | 2014-Ohio-2744
In re J.C. | 13-CA-83, 13-CA-84 | Permanent Custody | Hoffman | 6/23/2014 | 2014-Ohio-2743
Blythewood Farms, Ltd. v. Drown | 2013CA00025 | Small Claims Proceedings not in accord with Due Process | Hoffman | 6/23/2014 | 2014-Ohio-2742
State v. Butler | 14CA01 | Notification of post-release control consequences; allied offenses | Farmer | 6/20/2014 | 2014-Ohio-2758
Durben v. Malek | 2013 AP 08 0032 | Life estate; waste and conversion | Wise | 6/17/2014 | 2014-Ohio-2611
State v. Porter | 13CA89 | Assault of a police officer ineffective assistance; impeach witness | Hoffman | 6/16/2014 | 2014-Ohio-2680
State v. McCain | 13 CA 13 | Consecutive sentences | Wise | 6/16/2014 | 2014-Ohio-2594
Fields v. Bickle | CT2014-0002 | motion to dismiss - immunity | Farmer | 6/16/2014 | 2014-Ohio-2634
State v. Harris | 2013CA0013 | Withdraw plea | Gwin | 6/16/2014 | 2014-Ohio-2633
In re R.C. | 2014CA00023 | Permanent Custody | Farmer | 6/16/2014 | 2014-Ohio-2610
Collier v. Conley | 2013 CA 00166 | Trustee fees | Wise | 6/16/2014 | 2014-Ohio-2609
State v. Croskey | 13CA102 | Amended sentencing entry to include term of imprisonment for violation of community control. | Hoffman | 6/16/2014 | 2014-Ohio-2608
Ontario v. Eichar | 13CA92 | No contest plea | Hoffman | 6/16/2014 | 2014-Ohio-2607
Ware v. Ware | 13 CA 91 | Property division | Wise | 6/16/2014 | 2014-Ohio-2606
State v. McElfresh | 13 CA 73 | quashing of subpoena; motion to suppress | Wise | 6/16/2014 | 2014-Ohio-2605
State v. Smith | 13 CA 27 | Illegal manufacture methamphetamine; confession | Hoffman | 6/16/2014 | 2014-Ohio-2604
Craver v. Tomsic | 13 CAE 11 0078 | Arbitration Provision not waived by filing mechanic's lien. | Hoffman | 6/16/2014 | 2014-Ohio-2603
State v. Poulton | 13 CAA 07 0052 | Furnishing beer to a minor; Endangering a child | Hoffman | 6/16/2014 | 2014-Ohio-2602
Hurst v. Jobes, Henderson Assoc. | 13 CA 103 | Civ.R. 12(B)(6); 42 U.S.C. 1983 | Wise | 6/12/2014 | 2014-Ohio-2548
Bank of New York Mellon Trust Co., Natl. Assn. v. Loudermilk | 13-CA-75 | 60(B) - Foreclosure | Hoffman | 6/12/2014 | 2014-Ohio-2546
In re J.L. | CT2014-0010 | Permanent custody/Anders/Manifest weight | Baldwin | 6/11/2014 | 2014-Ohio-2684
Busch v. Hardway | 2013CA0021 | Replevin/Conversion/Horse/Manifest weight/Court costs | Baldwin | 6/11/2014 | 2014-Ohio-2681
State v. Dye | 13CA010 | Warrant Search - Motion to Suppress | Hoffman | 6/11/2014 | 2014-Ohio-2547
State v. Hamilton | 2013 AP 12 0061 | Motion to suppress statement | Baldwin | 6/10/2014 | 2014-Ohio-2685
State v. Harvey | 13-CA-109 | Expert testimony, mistrial, ineffective assistance of counsel | Gwin | 6/9/2014 | 2014-Ohio-2683
Motorists Mut. Ins. Co. v. King | 2013CA00231 | Insurance, insureds and exclusions | Gwin | 6/9/2014 | 2014-Ohio-2519
In re Estate of McCauley | 2013CA00193 | Exceptions | Gwin | 6/9/2014 | 2014-Ohio-2518
State v. Potts | 2013CA00168 | Domestic Violence; Manifest Weight of the Evidence | Delaney | 6/9/2014 | 2014-Ohio-2517
Anderson v. Massillon | 2013CA00144 | Political Subdivision Liability; Immunity of Employees | Delaney | 6/9/2014 | 2014-Ohio-2516
State v. Haley | 2014CA0002 | Manifest Weight | Gwin | 6/9/2014 | 2014-Ohio-2515
In re D.T. | 2013CA00252 | Legal Custody - Reasonable Efforts | Hoffman | 6/9/2014 | 2014-Ohio-2495
Harris v. Harris | 2013 CA 00199 | Jurisdiction of Probate Court | Wise | 6/9/2014 | 2014-Ohio-2494
State v. Brown | 13CA79 | Ineffective counsel; multiple counts/allied offenses | Farmer | 6/9/2014 | 2014-Ohio-2493
State v. Leak | 13CA72 | Motion to suppress; community control sanction overbroad; allied offenses | Farmer | 6/9/2014 | 2014-Ohio-2492

Page: [ 1] 2 3 4 next